.. Pyromaths documentation master file, created by
   sphinx-quickstart on Fri May 17 09:31:13 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Bienvenue !
===========

Ce document a pour objectif d'essayer de documenter le code de Pyromaths afin de permettre à un maximum de développeurs de participer au développement de Pyromaths en sachant quels modules sont déjà développés.

Table des matières
==================

.. toctree::
    :maxdepth: 1
    :numbered:

    intro
    ecrire
    modele
    pyromaths.api
    pyromaths.cli



Index des modules et fonctions
==============================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

